%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Application Note AN006
% Parameters for the 'Central PV inverter (three-phase grid-tied)' system
% Copyright imperix ltd, 2020
% dev@imperix.ch
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% SETPOINTS

VdcRef = 700; % DC bus voltage reference setpoint [V]
VdcMin = 540; % Minimal DC bus voltage to close bypass relay
Vdc0 = 500;   % Initial DC bus voltage [V]

%% SYSTEM PARAMETERS

SwitchingFreq = 16e3;           % Switching frequency [Hz]
Deadtime = 700e-9;              % Deadtime [s]

ControlFreq = SwitchingFreq;   % Control frequency [Hz]
ControlPeriod = 1/ControlFreq; % Control period [s]

SamplingPhase = 0.0;            % Sampling phase [-]

MpptFreq = 200;                 % MPPT execution frequency [Hz]
MpptPeriod = 1/200;             % MPPT execution period [s]

%% PLANT PARAMETERS

%PV
PvShortCircuitCurrent = 40; % PV panel's short-circuit current [A]
PvOpenCircuitVoltage = 300; % PV papKp_Ignel's open-circuit voltage [V]

Rpv = 6; % Parallel equivalent resistance of the PV [ohm]
Rs = 6;  % Serial equivalent resistance of the PV [ohm]

% Boost
Lb = 2.5e-3; % Boost-side inductor value [H]
Rb = 22e-3;  % Series equivalent resistance of Lb [ohm]

% Grid
GridFreq = 50; % Grid frequency [Hz]
Vg = 230;      % RMS Grid voltage [V]
Lg = 2.5e-3;   % Grid-side inductor value [H]
Rg = 22e-3;    % Series equivalent resistance of Lg [ohm]
Rp = 47;       % Grid precharge resistance [ohm]

%% BOOST CURRENT CONTROLLER PARAMETERS

% Optimum magnitude criterion
K1 = 1/Rb;
T1 = Lb/Rb;

% 1/2Ts of sampling, 1/2Ts of computation, 2/3 for the triangle carrier
Td1 = (1/2 + 1 + 1/2)*ControlPeriod; 

Tn1 = T1;
Ti1 = 2*K1*Td1;

KpIpv = Tn1/Ti1;
KiIpv = 1/Ti1;

%% GRID CURRENT CONTROLLER PARAMETERS (DQ)

% Optimum magnitude criterion
K2 = 1/Rg;
T2 = Lg/Rg;

Td2 = (1/2 + 1 + 1/2)*ControlPeriod; % 1/2Ts of sampling, 1/2Ts of computation, 2/3 for the triangle carrier

Tn2 = T2;
Ti2 = 2*K2*Td2;

KpIg = Tn2/Ti2;
KiIg = 1/Ti2;

%% CASCADED VOLTAGE CONTROLLER

KpVdc = 0.1;
KiVdc = 2;
